@@ -10,7 +10,7 @@ use ipaacar_core::components::buffer;
 use crate::input_buffer::InputBuffer;
 use crate::iu::IU;
 use crate::output_buffer::OutputBuffer;
-use pyo3_asyncio_0_21 as pyo3_asyncio; // https://github.com/awestlake87/pyo3-asyncio/issues/119
+use pyo3_async_runtimes as pyo3_asyncio; // https://github.com/awestlake87/pyo3-asyncio/issues/119
 
 pub mod input_buffer;
 pub mod iu;
